@@ -96,16 +96,12 @@ seriate_dist_mds <- function(x, control = NULL){
         return(order(sc[,1]))
     
     }else if(control$method == "isoMDS"){
-        if(require("MASS", quietly = TRUE)) {
-            sc <- isoMDS(x+1e-6, trace = FALSE, k=1)
-            return(order(sc$points[,1])) 
-        } else stop("Please install package MASS for this method.")
+        sc <- MASS::isoMDS(x+1e-6, trace = FALSE, k=1)
+        return(order(sc$points[,1])) 
     
     }else if(control$method == "sammon") {
-        if(require("MASS", quietly = TRUE)) {
-            sc <- sammon(x+1e-6, trace = FALSE, k=1)
-            return(order(sc$points[,1]))
-        } else stop("Please install package MASS for this method.")
+        sc <- MASS::sammon(x+1e-6, trace = FALSE, k=1)
+        return(order(sc$points[,1]))
 
     }else stop("unknown method")
 
